*** Egypt audit study: labor market discrimination experiment
*AUTHOR: Salma Rizk, Caroline Krafft
*Analysis do file
*Version 18 CK
*Orignal 2022.09.05
*Updated 2025.01.05 (R&R)


capture log close 
log using "${analysis}/13_Output/LMD RCT data analysis $S_DATE.log", replace

estimates clear

********************************************************************************
                               ****DATA ANALYSIS*****
********************************************************************************

*Analysis data file		
use "${analysis}/13_Output/finalmerged-3-2-2023.dta", clear

*Keep universe of applied
keep if callback!=.

*Table 1. Outcomes: Callback rates, by gender and marital status, N
table sex married [pw=sam_wt], c(mean callback) row col scol

*Percentage
gen callback_pct=callback*100

*Percentage
tabout sex married [aw=sam_wt] using "${analysis}/13_Output/LMD callbacks.xls", c(mean callback_pct) replace sum

*Ns
tabout sex married using "${analysis}/13_Output/LMD callbacks.xls", c(freq) append

*Table 2. Main model of callbacks for gender (spec. 1) and gender and marital status (spec. 2)

*Matrix for q-values
*Spec. 1
reg callback i.sex [pw=sam_wt], cluster(key)

estimates store main_s1

*H1
test 2.sex
estadd scalar H1=`r(p)'

sum callback [aw=sam_wt]
estadd scalar sam_mean=`r(mean)'

*Spec. 2
reg callback i.sex##i.married [pw=sam_wt], cluster(key)

estimates store main_s2

*H2 (single women vs. single men)
test 2.sex
estadd scalar H2=`r(p)'


*H3 (married vs. single men)
test 1.married
estadd scalar H3=`r(p)'

*H4 (single vs. married women)
test 1.married + 2.sex#1.married=0
estadd scalar H4=`r(p)'

*H5 (married women vs. married men)
test 2.sex + 2.sex#1.married=0
estadd scalar H5=`r(p)'

sum callback [aw=sam_wt]
estadd scalar sam_mean=`r(mean)'

***Output table
esttab main_s1 main_s2 using "${analysis}/13_Output/LMD main reg.csv", replace noomit nobase label cells(b(star fmt(%9.3f)) se(par)) ///
 stats(N N_clust r2 H1 H2 H3 H4 H5 sam_mean, fmt(%9.0g  %9.0g %9.3f) label("N (Posting-identity)" "N (postings)" "R-sq." "H1 p-value" "H2 p-value" "H3 p-value" "H4 p-value" "H5 p-value" "Mean of dep. var.")) ///
 coeflabel(1.married "Married" 2.sex#1.married "Female and married") ///
 refcat(2.sex "Sex (male omit.)" 1.married "Marital status (single omit.)", label(" "))



***Table 3 heterogeneity analysis
**By occupation
destring s1_occup1, replace
*Professional/managerial
gen prof_man=s1_occup1>=1 & s1_occup1<=2

reg callback i.sex if prof_man==1 [pw=sam_wt], cluster(key)
estimates store prof_1_s1

*H1
test 2.sex
estadd scalar H1=`r(p)'
matrix define forq=(`r(p)')

sum callback if prof_man==1  [aw=sam_wt]
estadd scalar sam_mean=`r(mean)'

reg callback i.sex if prof_man==0 [pw=sam_wt], cluster(key)
estimates store prof_0_s1

*H1
test 2.sex
estadd scalar H1=`r(p)'
matrix define forq=(forq,`r(p)')

sum callback if prof_man==0 [aw=sam_wt]
estadd scalar sam_mean=`r(mean)'


reg callback i.sex##i.married if prof_man==1 [pw=sam_wt], cluster(key)

estimates store prof_1_s2


*H2 (single women vs. single men)
test 2.sex
estadd scalar H2=`r(p)'
matrix define forq=(forq,`r(p)')


*H3 (married vs. single men)
test 1.married
estadd scalar H3=`r(p)'
matrix define forq=(forq,`r(p)')


*H4 (single vs. married women)
test 1.married + 2.sex#1.married=0
estadd scalar H4=`r(p)'
matrix define forq=(forq,`r(p)')


*H5 (married women vs. married men)
test 2.sex + 2.sex#1.married=0
estadd scalar H5=`r(p)'
matrix define forq=(forq,`r(p)')



reg callback i.sex##i.married if prof_man==0 [pw=sam_wt], cluster(key)
estimates store prof_0_s2


*H2 (single women vs. single men)
test 2.sex
estadd scalar H2=`r(p)'
matrix define forq=(forq,`r(p)')


*H3 (married vs. single men)
test 1.married
estadd scalar H3=`r(p)'
matrix define forq=(forq,`r(p)')

*H4 (single vs. married women)
test 1.married + 2.sex#1.married=0
estadd scalar H4=`r(p)'
matrix define forq=(forq,`r(p)')

*H5 (married women vs. married men)
test 2.sex + 2.sex#1.married=0
estadd scalar H5=`r(p)'
matrix define forq=(forq,`r(p)')



**By industry
*Service
gen service=s1_activity1>=10 & s1_activity1<=21

reg callback i.sex if service==1 [pw=sam_wt], cluster(key)
estimates store serv_1_s1


*H1
test 2.sex
estadd scalar H1=`r(p)'
matrix define forq=(forq,`r(p)')


sum callback if service==1 [aw=sam_wt]
estadd scalar sam_mean=`r(mean)'


reg callback i.sex if service==0 [pw=sam_wt], cluster(key)
estimates store serv_0_s1

*H1
test 2.sex
estadd scalar H1=`r(p)'
matrix define forq=(forq,`r(p)')

sum callback if service==0 [aw=sam_wt]
estadd scalar sam_mean=`r(mean)'



reg callback i.sex##i.married if service==1 [pw=sam_wt], cluster(key)
estimates store serv_1_s2


*H2 (single women vs. single men)
test 2.sex
estadd scalar H2=`r(p)'
matrix define forq=(forq,`r(p)')

*H3 (married vs. single men)
test 1.married
estadd scalar H3=`r(p)'
matrix define forq=(forq,`r(p)')

*H4 (single vs. married women)
test 1.married + 2.sex#1.married=0
estadd scalar H4=`r(p)'
matrix define forq=(forq,`r(p)')

*H5 (married women vs. married men)
test 2.sex + 2.sex#1.married=0
estadd scalar H5=`r(p)'
matrix define forq=(forq,`r(p)')


reg callback i.sex##i.married if service==0 [pw=sam_wt], cluster(key)
estimates store serv_0_s2


*H2 (single women vs. single men)
test 2.sex
estadd scalar H2=`r(p)'
matrix define forq=(forq,`r(p)')

*H3 (married vs. single men)
test 1.married
estadd scalar H3=`r(p)'
matrix define forq=(forq,`r(p)')

*H4 (single vs. married women)
test 1.married + 2.sex#1.married=0
estadd scalar H4=`r(p)'
matrix define forq=(forq,`r(p)')

*H5 (married women vs. married men)
test 2.sex + 2.sex#1.married=0
estadd scalar H5=`r(p)'
matrix define forq=(forq,`r(p)')


**By skills
tab1 *elmps*

*None required phyiscal fitness, only 20 literacy

foreach num of numlist 1 3 5/9 {
	foreach num2 of numlist 0/1 {
	
	di "`num'"
	
	reg callback i.sex if s5_elmpsskills_`num'==`num2' [pw=sam_wt], cluster(key)
	estimates store skill_`num'_`num2'_s1

	
	*H1
test 2.sex
estadd scalar H1=`r(p)'
matrix define forq=(forq,`r(p)')

sum callback if s5_elmpsskills_`num'==`num2' [aw=sam_wt]
estadd scalar sam_mean=`r(mean)'



	}
}

foreach num of numlist 1 3 5/9 {
	foreach num2 of numlist 0/1 {
	
	di "`num'"
	
	
	reg callback i.sex##i.married if s5_elmpsskills_`num'==`num2' [pw=sam_wt], cluster(key)
estimates store skill_`num'_`num2'_s2

*H2 (single women vs. single men)
test 2.sex
estadd scalar H2=`r(p)'
matrix define forq=(forq,`r(p)')

*H3 (married vs. single men)
test 1.married
estadd scalar H3=`r(p)'
matrix define forq=(forq,`r(p)')

*H4 (single vs. married women)
test 1.married + 2.sex#1.married=0
estadd scalar H4=`r(p)'
matrix define forq=(forq,`r(p)')

*H5 (married women vs. married men)
test 2.sex + 2.sex#1.married=0
estadd scalar H5=`r(p)'
matrix define forq=(forq,`r(p)')


	}
}

**Can't do education level, all higher education

**Not in PAP: By age requirement

reg callback i.sex if s2_age_req==1 [pw=sam_wt], cluster(key)
estimates store ager_1_s1


*H1
test 2.sex
estadd scalar H1=`r(p)'
matrix define forq=(forq,`r(p)')

sum callback if s2_age_req==1  [aw=sam_wt]
estadd scalar sam_mean=`r(mean)'


reg callback i.sex if s2_age_req==0 [pw=sam_wt], cluster(key)
estimates store ager_0_s1

*H1
test 2.sex
estadd scalar H1=`r(p)'
matrix define forq=(forq,`r(p)')


sum callback if s2_age_req==0  [aw=sam_wt]
estadd scalar sam_mean=`r(mean)'


reg callback i.sex##i.married if s2_age_req==1 [pw=sam_wt], cluster(key)
estimates store ager_1_s2


*H2 (single women vs. single men)
test 2.sex
estadd scalar H2=`r(p)'
matrix define forq=(forq,`r(p)')

*H3 (married vs. single men)
test 1.married
estadd scalar H3=`r(p)'
matrix define forq=(forq,`r(p)')

*H4 (single vs. married women)
test 1.married + 2.sex#1.married=0
estadd scalar H4=`r(p)'
matrix define forq=(forq,`r(p)')

*H5 (married women vs. married men)
test 2.sex + 2.sex#1.married=0
estadd scalar H5=`r(p)'
matrix define forq=(forq,`r(p)')


reg callback i.sex##i.married if s2_age_req==0 [pw=sam_wt], cluster(key)
estimates store ager_0_s2


*H2 (single women vs. single men)
test 2.sex
estadd scalar H2=`r(p)'
matrix define forq=(forq,`r(p)')

*H3 (married vs. single men)
test 1.married
estadd scalar H3=`r(p)'
matrix define forq=(forq,`r(p)')

*H4 (single vs. married women)
test 1.married + 2.sex#1.married=0
estadd scalar H4=`r(p)'
matrix define forq=(forq,`r(p)')

*H5 (married women vs. married men)
test 2.sex + 2.sex#1.married=0
estadd scalar H5=`r(p)'
matrix define forq=(forq,`r(p)')


**Not in PAP: By work experience

reg callback i.sex if (s4_workexpreq==1 & s4_workexpmin!=0) [pw=sam_wt], cluster(key)
estimates store wexpr_1_s1


*H1
test 2.sex
estadd scalar H1=`r(p)'
matrix define forq=(forq,`r(p)')


sum callback if (s4_workexpreq==1 & s4_workexpmin!=0)   [aw=sam_wt]
estadd scalar sam_mean=`r(mean)'



reg callback i.sex if (s4_workexpreq==0 | (s4_workexpreq==1 & s4_workexpmin==0)) [pw=sam_wt], cluster(key)
estimates store wexpr_0_s1

*H1
test 2.sex
estadd scalar H1=`r(p)'
matrix define forq=(forq,`r(p)')

sum callback if (s4_workexpreq==0 | (s4_workexpreq==1 & s4_workexpmin==0))   [aw=sam_wt]
estadd scalar sam_mean=`r(mean)'




reg callback i.sex##i.married if (s4_workexpreq==1 & s4_workexpmin!=0) [pw=sam_wt], cluster(key)
estimates store wexpr_1_s2


*H2 (single women vs. single men)
test 2.sex
estadd scalar H2=`r(p)'
matrix define forq=(forq,`r(p)')

*H3 (married vs. single men)
test 1.married
estadd scalar H3=`r(p)'
matrix define forq=(forq,`r(p)')

*H4 (single vs. married women)
test 1.married + 2.sex#1.married=0
estadd scalar H4=`r(p)'
matrix define forq=(forq,`r(p)')

*H5 (married women vs. married men)
test 2.sex + 2.sex#1.married=0
estadd scalar H5=`r(p)'
matrix define forq=(forq,`r(p)')


reg callback i.sex##i.married if (s4_workexpreq==0 | (s4_workexpreq==1 & s4_workexpmin==0)) [pw=sam_wt], cluster(key)
estimates store wexpr_0_s2


*H2 (single women vs. single men)
test 2.sex
estadd scalar H2=`r(p)'
matrix define forq=(forq,`r(p)')

*H3 (married vs. single men)
test 1.married
estadd scalar H3=`r(p)'
matrix define forq=(forq,`r(p)')

*H4 (single vs. married women)
test 1.married + 2.sex#1.married=0
estadd scalar H4=`r(p)'
matrix define forq=(forq,`r(p)')

*H5 (married women vs. married men)
test 2.sex + 2.sex#1.married=0
estadd scalar H5=`r(p)'
matrix define forq=(forq,`r(p)')

matrix list forq

***Output table
esttab prof_*_s1 serv_*_s1 ager_*_s1 wexpr_*_s1 skill_*_s1 prof_*_s2 serv_*_s2 ager_*_s2 wexpr_*_s2 skill_*_s2 using "${analysis}/13_Output/LMD het reg.csv", replace noomit nobase label cells(b(star fmt(%9.3f)) se(par)) ///
 stats(N N_clust r2 H1 H2 H3 H4 H5 sam_mean, fmt(%9.0g  %9.0g %9.3f) label("N (Posting-identity)" "N (postings)" "R-sq." "H1 p-value" "H2 p-value" "H3 p-value" "H4 p-value" "H5 p-value" "Mean of dep. var.")) ///
 coeflabel(1.married "Married" 2.sex#1.married "Female and married") ///
 refcat(2.sex "Sex (male omit.)" 1.married "Marital status (single omit.)" 2.sex#1.married "Int. marital status and sex", label(" "))


*Table 4. Callback outcomes by gender and marital status, individuals receiving a callback

tabu callback_type
tabu callback_type [aw=sam_wt]

gen schedule_interview=(callback_type==1)*100 if callback==1
gen more_info=(callback_type==2)*100 if callback==1
gen instant_interview=(callback_type==4)*100 if callback==1

tabout combined sex married [aw=sam_wt] using "${analysis}/13_Output/LMD scenarios.xls", c(mean schedule_interview mean more_info mean instant_interview) replace sum

*Table 5. Callback type models 

foreach var of varlist schedule_interview more_info instant_interview {

*Full sample dummy	
replace `var'=0 if callback!=1
replace `var'=1 if `var'==100
	
*Spec. 1
reg `var' i.sex [pw=sam_wt], cluster(key)

estimates store type_s1_`var'

*H1
test 2.sex
estadd scalar H1=`r(p)'

sum `var'  [aw=sam_wt]
estadd scalar sam_mean=`r(mean)'

*Spec. 2
reg `var' i.sex##i.married [pw=sam_wt], cluster(key)

estimates store type_s2_`var'

*H2 (single women vs. single men)
test 2.sex
estadd scalar H2=`r(p)'

*H3 (married vs. single men)
test 1.married
estadd scalar H3=`r(p)'

*H4 (single vs. married women)
test 1.married + 2.sex#1.married=0
estadd scalar H4=`r(p)'

*H5 (married women vs. married men)
test 2.sex + 2.sex#1.married=0
estadd scalar H5=`r(p)'

}

esttab type_s1_* type_s2_* using "${analysis}/13_Output/LMD callback type reg.csv", replace noomit nobase label cells(b(star fmt(%9.3f)) se(par)) ///
 stats(N N_clust r2 H1 H2 H3 H4 H5 sam_mean, fmt(%9.0g  %9.0g %9.3f) label("N (Posting-identity)" "N (postings)" "R-sq." "H1 p-value" "H2 p-value" "H3 p-value" "H4 p-value" "H5 p-value" "Mean of dep. var.")) ///
 coeflabel(1.married "Married" 2.sex#1.married "Female and married") ///
 refcat(2.sex "Sex (male omit.)" 1.married "Marital status (single omit.)" 2.sex#1.married "Int. marital status and sex", label(" "))

clear

matrix forq=forq'

****************************************************************
*Sharpened q-values (fdr_sharpened_qvalues.do from: http://are.berkeley.edu/~mlanderson/downloads/fdr_sharpened_qvalues.do.zip)
****************************************************************

* This code generates BKY (2006) sharpened two-stage q-values as described in Anderson (2008), "Multiple Inference and Gender Differences in the Effects of Early Intervention: A Reevaluation of the Abecedarian, Perry Preschool, and Early Training Projects", Journal of the American Statistical Association, 103(484), 1481-1495

* BKY (2006) sharpened two-stage q-values are introduced in Benjamini, Krieger, and Yekutieli (2006), "Adaptive Linear Step-up Procedures that Control the False Discovery Rate", Biometrika, 93(3), 491-507

* Last modified: M. Anderson, 11/20/07
* Test Platform: Stata/MP 10.0 for Macintosh (Intel 32-bit), Mac OS X 10.5.1
* Should be compatible with Stata 10 or greater on all platforms
* Likely compatible with with Stata 9 or earlier on all platforms (remove "version 10" line below)

version 10

****  INSTRUCTIONS:
****    Please start with a clear data set
****	When prompted, paste the vector of p-values you are testing into the "pval" variable
****	Please use the "do" button rather than the "run" button to run this file (if you use "run", you will miss the instructions at the prompts)

pause on
set more off

if _N > 0 {
	display "Please clear data set before proceeding"
	display "After clearing, type 'q' to resume"
	pause
}

svmat forq

rename forq1 pval


/*display "***********************************"
display "Please paste the vector of p-values that you wish to test into the variable 'pval'"
display	"After pasting, type 'q' to resume"
display "***********************************"

pause
*/

* Collect the total number of p-values tested

quietly sum pval
local totalpvals = r(N)

* Sort the p-values in ascending order and generate a variable that codes each p-value's rank

quietly gen int original_sorting_order = _n
quietly sort pval
quietly gen int rank = _n if pval != .

* Set the initial counter to 1 

local qval = 1

* Generate the variable that will contain the BKY (2006) sharpened q-values

gen bky06_qval = 1 if pval != .

* Set up a loop that begins by checking which hypotheses are rejected at q = 1.000, then checks which hypotheses are rejected at q = 0.999, then checks which hypotheses are rejected at q = 0.998, etc.  The loop ends by checking which hypotheses are rejected at q = 0.001.


while `qval' > 0 {
	* First Stage
	* Generate the adjusted first stage q level we are testing: q' = q/1+q
	local qval_adj = `qval' / ( 1 + `qval' )
	* Generate value q'*r/M
	gen fdr_temp1 = `qval_adj' * rank / `totalpvals'
	* Generate binary variable checking condition p(r) <= q'*r/M
	gen reject_temp1 = ( fdr_temp1 >= pval ) if pval != .
	* Generate variable containing p-value ranks for all p-values that meet above condition
	gen reject_rank1 = reject_temp1 * rank
	* Record the rank of the largest p-value that meets above condition
	egen total_rejected1 = max( reject_rank1 )

	* Second Stage
	* Generate the second stage q level that accounts for hypotheses rejected in first stage: q_2st = q'*(M/m0)
	local qval_2st = `qval_adj' * ( `totalpvals' / ( `totalpvals' - total_rejected1[1] ) )
	* Generate value q_2st*r/M
	gen fdr_temp2 = `qval_2st' * rank / `totalpvals'
	* Generate binary variable checking condition p(r) <= q_2st*r/M
	gen reject_temp2 = ( fdr_temp2 >= pval ) if pval != .
	* Generate variable containing p-value ranks for all p-values that meet above condition
	gen reject_rank2 = reject_temp2 * rank
	* Record the rank of the largest p-value that meets above condition
	egen total_rejected2 = max( reject_rank2 )

	* A p-value has been rejected at level q if its rank is less than or equal to the rank of the max p-value that meets the above condition
	replace bky06_qval = `qval' if rank <= total_rejected2 & rank != .
	* Reduce q by 0.001 and repeat loop
	drop fdr_temp* reject_temp* reject_rank* total_rejected*
	local qval = `qval' - .001
}


quietly sort original_sorting_order
pause off

display "Code has completed."
display "Benjamini Krieger Yekutieli (2006) sharpened q-vals are in variable 'bky06_qval'"
display	"Sorting order is the same as the original vector of p-values"

* Note: Sharpened FDR q-vals can be LESS than unadjusted p-vals when many hypotheses are rejected, because if you have many true rejections, then you can tolerate several false rejections too (this effectively just happens for p-vals that are so large that you are not going to reject them regardless).

list bky06_qval
*All 1


****************************************************************
*Appendix
****************************************************************

version 16.1

*Use ELMPS data, prepare a copy for comparison
use "${analysis}/11_Input/elmps 2018 xs v2.0 all.dta", clear

*Stat on starts in 2017
table dstcrj if usemp1==1 & usempstp==1 [pw=expan_indiv]

*Stat on # wage workers
table usempstp if usemp1==1 [pw=expan_indiv]

*Stat on online profile 
tabu q5216 [aw=expan_ind] if unemp1==1

*Stats on median age at marriage

gen evrmar=.
replace evrmar=0 if marital>=1 & marital<=3
replace evrmar=1 if marital>=4 & marital<=6

*age at first marriage or age of singles
gen agemarr=agemar1
replace agemarr=age if evrmar==0

*Check
tabu agemarr
replace agemarr=. if agemarr==98
replace agemarr=. if agemarr>age

stset agemarr if age>=18 & age<=39 & expan_indiv!=. [pw=expan_indiv], failure(evrmar=1) 

*Universal by 40
sts list, by(sex) failure

*By sex
stsum, by(sex)
*By sex, higher ed.
stsum if educ2>=7 & educ2<., by(sex)

*Stats on ability 
gen ability_cat=.
replace ability_cat=1 if sex==1 & marital>=1 & marital<=3
replace ability_cat=2 if sex==1 & marital==4
replace ability_cat=3 if sex==2 & marital>=1 & marital<=3
replace ability_cat=4 if sex==2 & marital==4

la def Lability_cat 1 "Male single" 2 "Male married" 3 "Female single" 4 "Female married"

la val ability_cat Lability_cat

*Are women selecting into the labor force?
tabu q3053 uslfsr1 if q3053!=98 & educ2>=7 & educ2<.& sex==2 [aw=expan_indiv], col nofreq

tabu q3053 sex if q3053!=98 & educ2>=7 & educ2<. [aw=expan_indiv], col nofreq

*University grade by sex and marital status, those in the labor force
tabout q3053 ability_cat if q3053!=98 & educ2>=7 & educ2<. & uslfsr1==1 [aw=expan_indiv] using "${analysis}/13_Output/ability.xls", replace cells(col)

tabout q3053 sex if q3053!=98 & educ2>=7 & educ2<. & uslfsr1==1 [aw=expan_indiv] using "${analysis}/13_Output/ability.xls", append cells(col)


*Workers
keep if usemp1==1

*Wage workers in the private sector
keep if usempstp==1
keep if ussectrp>=3 & ussectrp<.

*Generate dummies - occupations
tabu usocp1d, gen(usoc_)

labnoeq usoc_*

*Stat on occupations and gender
table usocp1d [pw=expan_ind], c(mean sex) row

*Mining with manufacturing
recode usecac1d (1=2)

*Utilities with construction
recode usecac1d (3/4=5)

*Financial and real estate with professional
recode usecac1d (10/11=12)

*Other services
recode usecac1d (17 19 14 =18)

*Education and health
recode usecac1d (15=16)

*Revise label
la def ecac1d  0 "Agriculture" 2 "Manufacturing and Mining" 5 "Construction and utilities" 6 "Retail and wholesale" 7 "Transport and storage" 8 "Accommodation and food service" 9 "Information and communication" 12 "Professional activities" 13 "Administrative and support" 16 "Education and Health" 18 "Other services", modify

fre usecac1d

tabu usecac1d, gen(usec_)

labnoeq usec_*

*Education required
*Recode
fre q6115
recode q6115 (3/4=2) (5=3) (6=4) (7=5) (98=.)

tabu q6115, gen(edreq_)

labnoeq edreq_*

la var edreq_1 "None/Undefined"
la var edreq_2 "Read & Write"
la var edreq_3 "Secondary"
la var edreq_4 "Bachelor"
la var edreq_5 "Post-graduate"

*Skills
gen technical=q6107==1
gen literacy=q6116_1==1
gen math=q6116_2==1
gen physical=q6116_3==1
gen computer=q6116_4==1
gen management=q6116_5==1
gen customer=q6116_6==1
gen foreign=q6116_7==1

la var technical "Technical"
la var literacy "Literacy"
la var math "Mathematics/statistics"
la var physical "Physical fitness"
la var computer "Computer"
la var management "Management"
la var customer "Customer service"
la var foreign "Foreign language"

*Wage 

rename expan_ind sam_wt

keep sam_wt gov usoc_1-foreign 

gen data="ELMPS 2018"

save "${analysis}/12_Temp/elmps compare.dta", replace


*Use job posting data
use "${analysis}/13_Output/finalmerged-3-2-2023.dta", clear

*Observation=posting
duplicates drop key, force

*N wages
fre s1_salaryav
tabu s1_salaryav if pos_applied==1
tabu s1_salaryav [aw=sam_wt] if pos_applied==1

*Occupation first digit
tabu s1_occup1, gen(usoc_)

rename usoc_8 usoc_9
rename usoc_7 usoc_8
rename usoc_6 usoc_7

gen usoc_6=0

la var usoc_1 "Managers"
la var usoc_2 "Professionals"
la var usoc_3 "Technicians & Assoc. Prof"
la var usoc_4 "Clerical"
la var usoc_5 "Service & Sales"
la var usoc_6 "Skilled Agric." 
la var usoc_7 "Craft & Related Trades" 
la var usoc_8 "Machine Op. & Assemblers" 
la var usoc_9 "Elementary Occupations"
/*labeling occupation first digit as per ISCO*/

*Recoding economic activities
gen usecac1d=s1_activity1

replace usecac1d=usecac1d-1

*Mining with manufacturing
recode usecac1d (1=2)

*Utilities with construction
recode usecac1d (3/4=5)

*Financial and real estate with professional
recode usecac1d (10/11=12)

*Other services
recode usecac1d (17 19 14 20 =18)

*Education and health
recode usecac1d (15=16)

la val usecac1d 

fre usecac1d

tabu usecac1d, gen(usec_)

la var usec_1 "Agriculture"
la var usec_2 "Manufacturing & Mining"
la var usec_3 "Construction & Utilities"
la var usec_4 "Wholesale & Retail"
la var usec_5 "Transportation & Storage"
la var usec_6 "Accommodation & Food Serv."
la var usec_7 "Information & Communication"
la var usec_8 "Financial Real Estate & Prof."
la var usec_9 "Administrative Support"
la var usec_10 "Education & Health"
la var usec_11 "Other Services"


*Education required
destring s3_edulevel s3_edulevelmsc, replace

replace s3_edulevel=0 if s3_edulevel==20
replace s3_edulevel=-1 if s3_edulevel==10

recode s3_edulevel (10=1) (20=2) (1/2=3) (5=4) (6/7=5)

tabu s3_edulevel, gen(edreq_)

la var edreq_1 "None/Undefined"
la var edreq_2 "Read & Write"
la var edreq_3 "Secondary"
la var edreq_4 "Bachelor"
la var edreq_5 "Post-graduate"

*Skills
gen technical=s5_elmpsskills_1==1
gen literacy=s5_elmpsskills_2==1
gen math=s5_elmpsskills_3==1
gen physical=s5_elmpsskills_4==1
gen computer=s5_elmpsskills_5==1
gen management=s5_elmpsskills_6==1
gen customer=s5_elmpsskills_7==1
gen foreign=s5_elmpsskills_8==1

la var technical "Technical"
la var literacy "Literacy"
la var math "Mathematics/Statistics"
la var physical "Physical fitness"
la var computer "Computer"
la var management "Management"
la var customer "Customer Service"
la var foreign "Foreign language"


*Governorate 
destring gov, replace

gen data="Job posting"

save "${analysis}/12_Temp/postings.dta", replace

*Figures

set scheme s1mono

use "${analysis}/12_Temp/postings.dta", clear

*Marital status
fre s2_marital if batch==1

*Gender
fre s2_gender_req if batch==1

*Cross-tabulation
tabu s2_maritalstatus s2_gender_req if batch==1

*N: positions
count if pos_applied==1
*N:resumes
tabu s2_maritalstatus s2_gender_req if pos_applied==1

*Resumes
di (622+7)*4+1*2+43*2+36*2

*******************
*Figure 1: Requirements
*******************
catplot s2_gender_req if batch==1 [aw=sam_wt], percent blabel(bar, pos(outside) format(%9.0f)) ylabel(0(20)100, nogrid) ytitle("Percentage of postings") l1title("") title("Gender requirements")

graph save "${analysis}/13_Output/gender_requirements.gph", replace
graph export "${analysis}/13_Output/gender_requirements.png", replace

*******************
*Appendix Table A3: Exclusion criteria
*******************



*Recoding into percentages

foreach num of numlist 1/13 {
	gen s1_exl_pct_`num'=s1_exclusioncriteria_`num'*100
}

gen expired_pct=expired*100

*Dummies
la var s1_exl_pct_1 "Included"
la var s1_exl_pct_2 "Public sector"
la var s1_exl_pct_3 "Job outside Egypt"
la var s1_exl_pct_4 "Job for non-Egyptians"
la var s1_exl_pct_5 "Position is volunteer"
la var s1_exl_pct_6 "Position req. 5+ yrs. exp."
la var s1_exl_pct_7 "Position is senior level"
la var s1_exl_pct_8 "Position too technical"
la var s1_exl_pct_9 "Position does not include ages 18-29"
la var s1_exl_pct_10 "Position req. license/certification"
la var s1_exl_pct_11 "Position req. additional docs."
la var s1_exl_pct_12 "Position req. profile not elsewhere"
la var s1_exl_pct_13 "Position org. confidential"

la var expired_pct "Expired"

*Table

tabform s1_exl_pct_* expired_pct [aw=sam_wt] using "${analysis}/13_Output/Exclusion percent.xls", vertical

tabout s1_exl_pct_* expired_pct using "${analysis}/13_Output/Exclusion N.xls", replace cells(freq) oneway


*******************
*Appendix Table A4: Occupations
*******************

*Occupations and industries from batch 1
keep if batch==1

*Requires female
gen req_female=(s2_gender_req==3)*100

*Requires male 
gen req_male=(s2_gender_req==2)*100

preserve 

destring s1_occup*, replace

collapse (count) s1_occup3, by(s1_occup6)

rename s1_occup3 freq

save "${analysis}/12_Temp/occup_n.dta", replace

restore

preserve 

destring s1_occup*, replace

collapse (mean) req_male req_female [aw=sam_wt], by(s1_occup6)

save "${analysis}/12_Temp/occup_req.dta", replace

restore

preserve 

destring s1_occup*, replace

collapse (sum) sam_wt, by(s1_occup6)

sum sam_wt, detail
replace sam_wt=sam_wt/`r(sum)'*100

merge 1:1 s1_occup6 using "${analysis}/12_Temp/occup_n.dta"

tabu _merge
drop _merge

merge 1:1 s1_occup6 using "${analysis}/12_Temp/occup_req.dta"

tabu _merge
drop _merge

gsort -sam_wt

rename sam_wt pct

keep if _n<20

isid pct

gsort -pct 
keep if _n<=10

la def Locc_6 251201 "Software developer" ///
243301 "Sales professionals" ///
333999 "Other business service agents" ///
422202 "Customer information call center clerk" ///
241101 "General accountant" ///
541402 "Security guard" ///
524999 "Other sales service workers" ///
821999 "Other equipment assemblers and installers" ///
242311 "General administration specialist" ///
243105 "Marketing specialist"

la val s1_occup6 Locc_6

save "${analysis}/12_Temp/occup_pct.dta", replace

export excel "${analysis}/13_Output/occup_pct.xls", replace first(var)

restore

/*
251201 Software developer
243301 Sales Professionals
333999 Business service agents not elsewhere classified and not to be classified - Others.
422202 Customer Information Call Center Clerk
241101 General Accountant
541402 security guard
524999 Sales service workers who were not classified - others
821999 Other equipment assemblers and installers not to be classified - Other
242311 General Administration Specialist
243105 Marketing Specialist
*/

*************
*Appendix Table A5: Industries
*******************

preserve 

destring s1_activity*, replace

collapse (count) s1_activity3, by(s1_activity6)

rename s1_activity3 freq

save "${analysis}/12_Temp/activity_n.dta", replace

restore

preserve 

destring s1_activity*, replace

collapse (mean) req_male req_female [aw=sam_wt], by(s1_activity6)

save "${analysis}/12_Temp/activity_req.dta", replace

restore

preserve 

destring s1_activity*, replace

collapse (sum) sam_wt, by(s1_activity6)

sum sam_wt, detail
replace sam_wt=sam_wt/`r(sum)'*100

merge 1:1 s1_activity6 using "${analysis}/12_Temp/activity_n.dta"

tabu _merge
drop _merge

merge 1:1 s1_activity6 using "${analysis}/12_Temp/activity_req.dta"

tabu _merge
drop _merge


gsort -sam_wt

rename sam_wt pct

keep if _n<20

isid pct

gsort -pct 
keep if _n<=10

la def Lactivity_6 829999 "Other ancillary business support services" ///
783000 "Human resources supply and management" ///
620999 "Other activities of computer and information systems" ///
639999 "Other information services activities" ///
329099 "Other activities of other manufacturing industries" ///
639901 "Information-based telephone services" ///
620199 "Other computer software activities" ///
682001 "Activities of real estate agencies and brokers" ///
439099 "Other construction activities" ///
562999 "Other activities for other food services"

la val s1_activity6 Lactivity_6

save "${analysis}/12_Temp/activity_pct.dta", replace

export excel "${analysis}/13_Output/activity_pct.xls", replace first(var)

restore

/*
829999 Administrative and support services 829 Business support services activities not elsewhere classified  Other ancillary services for projects not elsewhere classified
783000 Human resources supply activities and management functions of these resources
620999 Other activities of other information systems and computer services activities
639999 Other information services activities
329099 Other activities of other manufacturing industries, not elsewhere classified
639901 Information-Based Telephone Services
620199 Other computer software activities
682001 Activities of real estate agencies and brokers
439,099 Other construction activities
562999 Other activities for other food services

*/

clear

*******************
*Appendix Table A1: Versus ELMPS, re-weighting 
*******************

*Need an old version of iebaltab 
do "${analysis}/01_DoFiles/iebaltab.ado"	

use "${analysis}/12_Temp/elmps compare.dta", clear

*Stat on occupations 

append using "${analysis}/12_Temp/postings.dta"

*Governorate 
tabu gov, gen(gov_)
labnoeq gov_*

*Batch 1
gen ds_data=1 if data=="Job posting" & batch==1
replace ds_data=2 if data=="ELMPS 2018"

la def Lds_data 1 "Job posting" 2 "ELMPS 2018"
la val ds_data Lds_data

iebaltab usoc_1 usoc_2 usoc_3 usoc_4 usoc_5 usoc_6 usoc_7 usoc_8 usoc_9 usec_1 usec_2 usec_3 usec_4 usec_5 usec_6 usec_7 usec_8 usec_9 usec_10 usec_11 edreq_1 edreq_2 edreq_3 edreq_4 edreq_5 technical literacy math physical computer management customer foreign  [aw=sam_wt], grpvar(ds_data) replace save("${analysis}/13_Output/posting elmps.xls") starlevels(0.05 0.01 0.001) rowvarlabels 

*Dummy for job data
replace ds_data=0 if ds_data==2
replace ds_data=1 if batch==2

*Creating a weight by pooling 
logit ds_data usoc_1 usoc_2 usoc_3 usoc_4 usoc_5 usoc_6 usoc_7 usoc_8 usoc_9 usec_1 usec_2 usec_3 usec_4 usec_5 usec_6 usec_7 usec_8 usec_9 usec_10 usec_11 edreq_1 edreq_2 edreq_3 edreq_4 edreq_5 technical literacy math physical computer management customer foreign [pw=sam_wt]

*Predicted probability
predict pr_posting if ds_data==1, pr

*Inverse probability weight 
gen ip_wt=sam_wt*(1-pr_posting)/pr_posting

sum pr_posting ip_wt sam_wt if ds_data==1

*Keep universe of applied
keep if callback!=.

isid key

keep key ip_wt 

save "${analysis}/12_Temp/reweight.dta", replace

*Analysis data file		
use "${analysis}/13_Output/finalmerged-3-2-2023.dta", clear

*Keep universe of applied
keep if callback!=.

merge m:1 key using "${analysis}/12_Temp/reweight.dta"

*Table X. Main model of callbacks for gender (spec. 1) and gender and marital status (spec. 2) re-weighted

*Spec. 1
reg callback i.sex [pw=ip_wt], cluster(key)

estimates store main_s1_ipwt

*H1
test 2.sex
estadd scalar H1=`r(p)'

sum callback [aw=ip_wt]
estadd scalar sam_mean=`r(mean)'


*Spec. 2
reg callback i.sex##i.married [pw=ip_wt], cluster(key)

estimates store main_s2_ipwt

*H2 (single women vs. single men)
test 2.sex
estadd scalar H2=`r(p)'


*H3 (married vs. single men)
test 1.married
estadd scalar H3=`r(p)'

*H4 (single vs. married women)
test 1.married + 2.sex#1.married=0
estadd scalar H4=`r(p)'

*H5 (married women vs. married men)
test 2.sex + 2.sex#1.married=0
estadd scalar H5=`r(p)'


***Output table
esttab main_s1_ipwt main_s2_ipwt using "${analysis}/13_Output/LMD main reg. ipwt.csv", replace noomit nobase label cells(b(star fmt(%9.3f)) se(par)) ///
 stats(N N_clust r2 H1 H2 H3 H4 H5 sam_mean, fmt(%9.0g  %9.0g %9.3f) label("N (Posting-identity)" "N (postings)" "R-sq." "H1 p-value" "H2 p-value" "H3 p-value" "H4 p-value" "H5 p-value" "Mean of dep. var.")) ///
 coeflabel(1.married "Married" 2.sex#1.married "Female and married") ///
 refcat(2.sex "Sex (male omit.)" 1.married "Marital status (single omit.)", label(" "))


*******************
*Appendix Table A2: Details of position requirements
*******************

*% age req. 

use "${analysis}/12_Temp/postings.dta", clear

*Keep only batch 1 
keep if batch==1

gen pct_s2_age_req=s2_age_req*100

*Age minimum and maximum
fre s2_agemin s2_agemax

*Work experience
*specified (added later)
*Experience minimum and maximum 
fre s4_workexpmin s4_workexpmax

*Minimum categorically
foreach num of numlist 0/5 {
	gen pct_s4_workexpreq_`num'=(s4_workexpmin==`num')*100
}

*Zero includes none mentioned
replace pct_s4_workexpreq_0=100 if s4_workexpreq==0

gen pct_s4_workexpreq_plus=(s4_workexpmin>=6 & s4_workexpmin<.)*100

la var pct_s2_age_req "Has Age Requirement (%)"
la var s2_agemin "Minimum Age"
la var s2_agemax "Maximum Age"
la var pct_s4_workexpreq_0 "No Experience"
la var pct_s4_workexpreq_1 "1 Year Experience"
la var pct_s4_workexpreq_2 "2 Year Experience"
la var pct_s4_workexpreq_3 "3 Year Experience"
la var pct_s4_workexpreq_4 "4 Year Experience"
la var pct_s4_workexpreq_5 "5 Year Experience"
la var pct_s4_workexpreq_plus "More Than 5 Year Experience"

*Driver's license
gen pct_s1_drivinglicence=s1_drivinglicence*100
la var pct_s1_drivinglicence "Requires Driver's License"

*Table with these 
tabform pct_s2_age_req s2_agemin s2_agemax pct_s4_workexpreq_0 pct_s4_workexpreq_1 pct_s4_workexpreq_2 pct_s4_workexpreq_3 pct_s4_workexpreq_4 pct_s4_workexpreq_5 pct_s4_workexpreq_plus pct_s1_drivinglicence [aw=sam_wt] using "${analysis}/13_Output/Details of position.xls", vertical

*Skills next, reshape and take modes 1-10 
isid key
reshape long s5_skillstech_@ s5_skillsoft_@, i(key) j(skill_no)

rename s5_skillstech_ s5_s1
rename s5_skillsoft_ s5_s2

reshape long s5_s@, i(key skill_no) j(skill_type)

*Drop missing
drop if s5_s==""
drop if s5_s=="0"

*Make lower
replace s5_s=lower(s5_s)

*Remove common unneeded words
replace s5_s=subinstr(s5_s,"knowledge"," ",.)
replace s5_s=subinstr(s5_s,"skills"," ",.)
replace s5_s=subinstr(s5_s,"experience"," ",.)
replace s5_s=subinstr(s5_s,"ability"," ",.)
replace s5_s=subinstr(s5_s,"understanding"," ",.)
replace s5_s=subinstr(s5_s,"excellent"," ",.)
replace s5_s=subinstr(s5_s,"strong"," ",.)
replace s5_s=subinstr(s5_s,"command"," ",.)
replace s5_s=subinstr(s5_s,"working"," ",.)
replace s5_s=subinstr(s5_s,"problem solving","problem-solving",.)


drop if s5_s==""

*Expand 
expand sam_wt*3

*Keep just needed variable
keep s5_s

*Save a file 
export delimited using "${analysis}/12_Temp/skill_words.csv", replace

clear
*Freqeuncies
wordfreq using "${analysis}/12_Temp/skill_words.csv", min_length(4) nogrammar nocommon

sum freq, detail

gen pct=freq/`r(sum)'*100

gsort -pct

keep if _n<=20

isid pct



keep if _n<=10

export excel "${analysis}/13_Output/skill_words.xls", replace




*******************
*SA: Photo and name checks
*******************

*Analysis data file		
use "${analysis}/13_Output/finalmerged-3-2-2023.dta", clear

*By sex: photos and name

reg callback i.photo_no i.applicant_name if sex==1 [pw=sam_wt], cluster(key)
reg callback i.photo_no i.applicant_name if sex==2 [pw=sam_wt], cluster(key)


*******************
*SA: Controls and re-weighting 
*******************

*Analysis data file		
use "${analysis}/13_Output/finalmerged-3-2-2023.dta", clear

*Occupation first digit
tabu s1_occup1, gen(usoc_)

rename usoc_8 usoc_9
rename usoc_7 usoc_8
rename usoc_6 usoc_7

gen usoc_6=0

la var usoc_1 "Managers"
la var usoc_2 "Professionals"
la var usoc_3 "Technicians & Assoc. Prof"
la var usoc_4 "Clerical"
la var usoc_5 "Service & Sales"
la var usoc_6 "Skilled Agric." 
la var usoc_7 "Craft & Related Trades" 
la var usoc_8 "Machine Op. & Assemblers" 
la var usoc_9 "Elementary Occupations"
/*labeling occupation first digit as per ISCO*/

*Recoding economic activities
gen usecac1d=s1_activity1

replace usecac1d=usecac1d-1

*Mining with manufacturing
recode usecac1d (1=2)

*Utilities with construction
recode usecac1d (3/4=5)

*Financial and real estate with professional
recode usecac1d (10/11=12)

*Other services
recode usecac1d (17 19 14 20 =18)

*Education and health
recode usecac1d (15=16)

la val usecac1d 

fre usecac1d

tabu usecac1d, gen(usec_)

la var usec_1 "Agriculture"
la var usec_2 "Manufacturing & Mining"
la var usec_3 "Construction & Utilities"
la var usec_4 "Wholesale & Retail"
la var usec_5 "Transportation & Storage"
la var usec_6 "Accommodation & Food Serv."
la var usec_7 "Information & Communication"
la var usec_8 "Financial Real Estate & Prof."
la var usec_9 "Administrative Support"
la var usec_10 "Education & Health"
la var usec_11 "Other Services"


*Education required
destring s3_edulevel s3_edulevelmsc, replace

replace s3_edulevel=0 if s3_edulevel==20
replace s3_edulevel=-1 if s3_edulevel==10

recode s3_edulevel (10=1) (20=2) (1/2=3) (5=4) (6/7=5)

tabu s3_edulevel, gen(edreq_)

la var edreq_1 "None/Undefined"
la var edreq_2 "Read & Write"
la var edreq_3 "Secondary"
la var edreq_4 "Bachelor"
la var edreq_5 "Post-graduate"

*Skills
gen technical=s5_elmpsskills_1==1
gen literacy=s5_elmpsskills_2==1
gen math=s5_elmpsskills_3==1
gen physical=s5_elmpsskills_4==1
gen computer=s5_elmpsskills_5==1
gen management=s5_elmpsskills_6==1
gen customer=s5_elmpsskills_7==1
gen foreign=s5_elmpsskills_8==1

la var technical "Technical"
la var literacy "Literacy"
la var math "Mathematics/Statistics"
la var physical "Physical fitness"
la var computer "Computer"
la var management "Management"
la var customer "Customer Service"
la var foreign "Foreign language"

*Keep universe of applied
keep if callback!=.


*Table X. Main model of callbacks for gender (spec. 1) and gender and marital status (spec. 2)

*Matrix for q-values
*Spec. 1
reg callback i.sex usoc_2 usoc_3 usoc_4 usoc_5 usoc_7 usoc_8 usoc_9 usoc_6 usec_1 usec_2 usec_3 usec_5 usec_6 usec_7 usec_8 usec_9 usec_10 usec_11 edreq_1 edreq_2 edreq_3 edreq_5 technical literacy math physical computer management customer foreign b1.gov [pw=sam_wt], cluster(key)

estimates store main_s1_cont

*H1
test 2.sex
estadd scalar H1=`r(p)'

sum callback  [aw=sam_wt]
estadd scalar sam_mean=`r(mean)'


*Spec. 2
reg callback i.sex##i.married usoc_2 usoc_3 usoc_4 usoc_5 usoc_7 usoc_8 usoc_9 usoc_6 usec_1 usec_2 usec_3 usec_5 usec_6 usec_7 usec_8 usec_9 usec_10 usec_11 edreq_1 edreq_2 edreq_3 edreq_5 technical literacy math physical computer management customer foreign b1.gov [pw=sam_wt], cluster(key)

estimates store main_s2_cont

*H2 (single women vs. single men)
test 2.sex
estadd scalar H2=`r(p)'


*H3 (married vs. single men)
test 1.married
estadd scalar H3=`r(p)'

*H4 (single vs. married women)
test 1.married + 2.sex#1.married=0
estadd scalar H4=`r(p)'

*H5 (married women vs. married men)
test 2.sex + 2.sex#1.married=0
estadd scalar H5=`r(p)'


***Output table
esttab main_s1_cont main_s2_cont using "${analysis}/13_Output/LMD main reg controls.csv", replace noomit nobase label cells(b(star fmt(%9.3f)) se(par)) ///
 stats(N N_clust r2 H1 H2 H3 H4 H5 sam_mean, fmt(%9.0g  %9.0g %9.3f) label("N (Posting-identity)" "N (postings)" "R-sq." "H1 p-value" "H2 p-value" "H3 p-value" "H4 p-value" "H5 p-value" "Mean of dep. var.")) ///
 order(2.sex 1.married 2.sex#1.married) ///
 coeflabel(1.married "Married" 2.sex#1.married "Female and married") ///
 refcat(2.sex "Sex (male omit.)" 1.married "Marital status (single omit.)", label(" "))
 
*******************
*Osman et al. (2025) discrimination calculations
*******************

use "${analysis}/11_Input/Egypt-Economic_Census-2017(V1).dta", clear

*Keep the four industries examined (retail, ICT, hotels, restaurants)
*1 digit, assuming sampled on 1 digit 
keep if inlist(ecoact1d, 7,9,10)
drop if ecoact2d==45 | ecoact2d==46

*Private sector
keep if sector==2

/*Parameter for favoring men - average for direct question must be at average size
for industry, note their calculations included only 5+ so using that for average size
Solving for parameter varying from average size */

gen average_size=. 
*Retail
sum tab1_1_Worker [aw=weight] if ecoact1d==7 & tab1_1_Worker>=5
replace average_size=`r(mean)' if ecoact1d==7
*ICT
sum tab1_1_Worker [aw=weight] if ecoact1d==10 & tab1_1_Worker>=5
replace average_size=`r(mean)' if ecoact1d==10
*Hotels
sum tab1_1_Worker [aw=weight] if ecoact2d==55 & tab1_1_Worker>=5
replace average_size=`r(mean)' if ecoact2d==55
*Restaurants 
sum tab1_1_Worker [aw=weight] if ecoact2d==56 & tab1_1_Worker>=5
replace average_size=`r(mean)' if ecoact2d==56

*Average favoritism
gen average_favor=.

*Retail
replace average_favor=.601 if ecoact1d==7

*ICT
replace average_favor=.164 if ecoact1d==10

*Hotel
replace average_favor=.437 if ecoact2d==55

*Restaurants
replace average_favor=.555 if ecoact2d==56

*Favoritism calculations
gen favor=average_favor+0.004*average_size-0.004*tab1_1_Worker

*Check recover mean establishment
bysort ecoact1d: sum favor [aw=weight] if tab1_1_Worker>=5
bysort ecoact2d: sum favor [aw=weight] if tab1_1_Worker>=5

*Create employee level weight
gen re_weight=weight*tab1_1_Worker

*Favoritism on employee level
sum favor [aw=re_weight]

bysort ecoact1d: sum favor [aw=re_weight]
bysort ecoact2d: sum favor [aw=re_weight]

log close
